local mod = ...

--[[

	Adds chicken yards that produce chicken meat and eggs, early and cheap food.
	Also produces dung for vegetable gardens.

]]--


-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "POULTRYFARMER_JOB",
	JobName = "POULTRYFARMER_JOB_NAME",
	JobDescription = "POULTRYFARMER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	-- UseWorkplaceBehavior = true,
    ProductionDelay = 80.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		-- RightHandObject = {
		-- 	DataType = "HAND_OBJECT",
		-- 	Model = "PREFAB_TOOL_FARMER_SEED_BAG"
		-- },
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "POULTRYFARMER_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "POULTRYFARMER_JOB"
    }
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Chicken.png", "ICON_CHICKEN")

mod:register({
	DataType = "RESOURCE",
	Id = "CHICKEN_RESOURCE",
	ResourceName = "CHICKEN_RESOURCE_NAME",
	Icon = "ICON_CHICKEN",
	ResourceTypeList = { "FOOD" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 4 },
	DisplayInInventory = true
})

mod:registerAssetId("icons/Egg.png", "ICON_EGG")

mod:register({
	DataType = "RESOURCE",
	Id = "EGG_RESOURCE",
	ResourceName = "EGG_RESOURCE_NAME",
	Icon = "ICON_EGG",
	ResourceTypeList = { "FOOD" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})



-- Assets
mod:registerAssetId("models/ChickenYard.fbx/Prefab/ChickenYardPart/Chicken.001", "PREFAB_CHICKEN")

mod:registerAssetId("models/ChickenYard.fbx/Prefab/ChickenYardPart", "PREFAB_CHICKENYARD")
mod:registerAssetId("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart", "PREFAB_CHICKENYARD_CHICKEN")
mod:registerAssetId("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart", "PREFAB_CHICKENYARD_EGGS")



-- Building Asset Processor
mod:registerAssetProcessor("models/ChickenYard.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/ChickenYardChicken.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/ChickenYardEggs.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Construction visual
mod:registerAssetId("models/ChickenYard.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_CHICKENYARD")



-- Dirt rectangle
mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {5.0, 5.0} })
mod:registerPrefabComponent("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {5.0, 5.0} })
mod:registerPrefabComponent("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {5.0, 5.0} })



-- Grounding construction visuals
for i=1, 20, 1 do
	mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding fences
for i=1, 20, 1 do
	mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding chickens
for i=1, 10, 1 do
	mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart/Chicken." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart/Chicken." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart/Chicken." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding baskets
for i=1, 5, 1 do
	mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart/Basket." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart/Basket." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding chicken house and stump
mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart/House.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart/House.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/ChickenYardEggs.fbx/Prefab/ChickenYardPart/House.001", {DataType = "COMP_GROUNDED"})

mod:registerPrefabComponent("models/ChickenYard.fbx/Prefab/ChickenYardPart/StumpAxe", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/ChickenYardChicken.fbx/Prefab/ChickenYardPart/StumpAxe", {DataType = "COMP_GROUNDED"})



-- Building Function: Chicken yard  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_FUNCTION",
    Name = "CHICKENYARD_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 1 },
		{ Resource = "EGG_RESOURCE", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Function: Chicken meat  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_CHICKEN_FUNCTION",
    Name = "CHICKENYARD_CHICKEN_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 1 },
		-- { Resource = "EGG_RESOURCE", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Function: Chicken eggs  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_EGGS_FUNCTION",
    Name = "CHICKENYARD_EGGS_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		-- { Resource = "CHICKEN_RESOURCE", Quantity = 1 },
		{ Resource = "EGG_RESOURCE", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Part: Placeholder -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKEN_PART",
	Name = "CHICKENYARD_NAME", 
	Description = "CHICKENYARD_DESC",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKEN"
	},
	IsVisibleWhenBuilt = false
})



-- Building -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING", 
	Id = "CHICKENYARD",
	Name = "CHICKENYARD_NAME",
	Description = "CHICKENYARD_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "CHICKEN_PART",
	BuildingPartSetList = {
		{
			Name = "CHICKENYARD_SET_NAME",
			BuildingPartList = { 
				"CHICKENYARD_PART",
				"CHICKENYARD_CHICKEN_PART",
				"CHICKENYARD_EGGS_PART"
			}
		}
	},	
	RequiredPartList = {
		{ Category = "CORE", Quantity = 1 }
	},
	IsEditable = true
})



-- Building Part: Chicken yard -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKENYARD_PART",
	Name = "CHICKENYARD_PART_NAME", 
	Description = "CHICKENYARD_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKENYARD"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHICKENYARD",
	BuildingZone = {
		DataType = "BUILDING_ZONE",
		Polygon = {
			{3, 3},
			{3, -3},
			{-3, -3},
			{-3, 3}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 }
		}
	}
})



-- Building Part: Chicken yard for meat only -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKENYARD_CHICKEN_PART",
	Name = "CHICKENYARD_CHICKEN_PART_NAME", 
	Description = "CHICKENYARD_CHICKEN_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKENYARD_CHICKEN"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHICKENYARD",
	BuildingZone = {
		DataType = "BUILDING_ZONE",
		Polygon = {
			{3, 3},
			{3, -3},
			{-3, -3},
			{-3, 3}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_CHICKEN_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 }
		}
	}
})



-- Building Part: Chicken yard for eggs only -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKENYARD_EGGS_PART",
	Name = "CHICKENYARD_EGGS_PART_NAME", 
	Description = "CHICKENYARD_EGGS_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKENYARD_EGGS"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHICKENYARD",
	BuildingZone = {
		DataType = "BUILDING_ZONE",
		Polygon = {
			{3, 3},
			{3, -3},
			{-3, -3},
			{-3, 3}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_EGGS_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 }
		}
	}
})
